// WARNING: Please don't edit this file. It was generated by Python/WinRT v2.0.0-beta.1

#include "py.Windows.Media.Render.h"


namespace py::cpp::Windows::Media::Render
{
    // ----- Windows.Media.Render Initialization --------------------
    PyDoc_STRVAR(module_doc, "Windows::Media::Render");


    static PyModuleDef module_def
        = {PyModuleDef_HEAD_INIT,
           "_winrt_windows_media_render",
           module_doc,
           0,
           nullptr,
           nullptr,
           nullptr,
           nullptr,
           nullptr};

} // py::cpp::Windows::Media::Render

PyMODINIT_FUNC PyInit__winrt_windows_media_render(void) noexcept
{
    using namespace py::cpp::Windows::Media::Render;

    if (py::import_winrt_runtime() == -1)
    {
        return nullptr;
    }

    py::pyobj_handle module{PyModule_Create(&module_def)};

    if (!module)
    {
        return nullptr;
    }

    auto object_type = py::get_object_type();
    if (!object_type)
    {
        return nullptr;
    }

    py::pyobj_handle object_bases{PyTuple_Pack(1, object_type)};

    if (!object_bases)
    {
        return nullptr;
    }


    return module.detach();
}
